#!/bin/sh

start on started rcS-late

script
#The swappiness parameter controls the tendency of the kernel to 
#move processes out of physical memory and onto the swap disk. 
#Because disks are much slower than RAM, this can lead to slower response 
#times for system and applications if processes are too aggressively moved out of memory.
#Default = 100

echo "30" > /proc/sys/vm/swappiness

#Page-cluster controls the number of pages which are written to swap in a single attempt. 
#The swap I/O size.It is a logarithmic value - setting it to zero means "1 page",
#setting it to 1 means "2 pages" setting it to 2 means "4 pages", etc. 
#The default value is 5 (eight pages at a time). 
#There may be some small benefits in tuning this to a different value if your workload is swap-intensive.
#Default = 5

#echo "6" > /proc/sys/vm/page-cluster

#laptop_mode is a knob that controls "laptop mode". When the knob is set, any physical disk I/O 
#(that might have caused the hard disk to spin up) causes Linux to flush all dirty blocks.
#The result of this is that after a disk has spun down, it will not be spun up anymore to write dirty blocks
#because those blocks had already been written immediately after the most recent read operation.
#The value of the laptop_mode knob determines the time between the occurrence of disk I/O and when the flush is triggered.
#A sensible value for the knob is 5 seconds. Setting the knob to 0 disables laptop mode.

#echo "1" > /proc/sys/vm/laptop_mode

#This enables or disables killing the OOM-triggering task in out-of-memory situations.
#If this is set to zero, the OOM killer will scan through the entire tasklist and select a task based on heuristics to kill. 
#This normally selects a rogue memory-hogging task that frees up a large amount of memory when killed.
#If this is set to non-zero, the OOM killer simply kills the task that triggered the out-of-memory condition.
#This avoids the expensive tasklist scan. If panic_on_oom is selected, it takes precedence over whatever value is used in oom_kill_allocating_task.
##Default = 0

#echo "1" > /proc/sys/vm/oom_kill_allocating_task

#This tunable is used to define when dirty data is old enough to be eligible for writeout by the pdflush daemons. 
#It is expressed in 100'ths of a second. Data which has been dirty in memory for longer than this interval will be 
#written out next time a pdflush daemon wakes up.
#Default = 500

echo "2000" > /proc/sys/vm/dirty_expire_centisecs

#The pdflush writeback daemons will periodically wake up and write "old" data out to disk.
#This tunable expresses the interval between those wakeups, in 100'ths of a second.
#Setting this to zero disables periodic writeback altogether.
#Default = 500

echo "2000" > /proc/sys/vm/dirty_writeback_centisecs

#Normally, TCP will remember some characteristics about the last connection in the flow cache. 
#If tcp_no_metrics_save is set, then it doesn't. Useful for benchmarks or other tests.

#echo "0" > /proc/sys/net/ipv4/tcp_timestamps
#echo "1" > /proc/sys/net/ipv4/tcp_no_metrics_save

#To free pagecache, change this value to "1"
#To free dentries and inodes, change this value to "2"
#Using a value of "3" presents a non-destructive operation and will only free things that are completely unused. 
#Dirty objects will continue to be in use until written out to disk and are not freeable. 
#If you run "sync" first to flush them out to disk, these drop operations will tend to free more memory.
#Default = 0

echo "2" > /proc/sys/vm/drop_caches

#Ratio of total pages to free pages for each memory zone.
#Default = 32

echo "22" > /proc/sys/vm/lowmem_reserve_ratio

#Wait until late in the boot process

sleep 45

#Contains, as a percentage of total system memory, the number of pages at which the pdflush background writeback daemon 
#will start writing out dirty data.
#Default = 10

#echo "5" > /proc/sys/vm/dirty_background_ratio       

#Contains, as a percentage of total system memory, the number of pages at which a process which is generating disk writes
#will itself start writing out dirty data.
#Default = 60

echo "95" > /proc/sys/vm/dirty_ratio

#Turn off capture volume
amixer set Capture 0%
amixer set Capture nocap
       
#Wait 15 secs

sleep 15

#Turn on Capture Volume
amixer set Capture cap
amixer set Capture 100%

end script